Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: content/public/browser/content_browser_client.h

Issue 859213006: Cancel client auth requests when not promptable. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@client-auth-cancel-1
Patch Set: extension test Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/content_browser_client.h
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h
index d2ae7a0dd59c07dd4157d4eb2683965cb4bb539e..63f6f6ab5a6d32f42a07922275011dbd6dc60b8a 100644
--- a/content/public/browser/content_browser_client.h
+++ b/content/public/browser/content_browser_client.h
@@ -89,6 +89,7 @@ class BrowserMainParts;
class BrowserPluginGuestDelegate;
class BrowserPpapiHost;
class BrowserURLHandler;
+class ClientCertificateDelegate;
class DevToolsManagerDelegate;
class ExternalVideoSurfaceContainer;
class LocationProvider;
@@ -398,14 +399,14 @@ class CONTENT_EXPORT ContentBrowserClient {
const base::Callback<void(bool)>& callback,
CertificateRequestResultType* result) {}
// Selects a SSL client certificate and returns it to the |callback|. If no
// certificate was selected nullptr is returned to the |callback|. Note:
// |callback| may be called synchronously or asynchronously.
virtual void SelectClientCertificate(
- int render_process_id,
- int render_frame_id,
+ WebContents* web_contents,
net::SSLCertRequestInfo* cert_request_info,
- const base::Callback<void(net::X509Certificate*)>& callback);
+ scoped_ptr<ClientCertificateDelegate> delegate);
// Adds a new installable certificate or private key.
// Typically used to install an X.509 user certificate.
@@ -398,14 +399,14 @@ class CONTENT_EXPORT ContentBrowserClient {
const base::Callback<void(bool)>& callback,
CertificateRequestResultType* result) {}
- // Selects a SSL client certificate and returns it to the |callback|. If no
- // certificate was selected nullptr is returned to the |callback|. Note:
- // |callback| may be called synchronously or asynchronously.
+ // Selects a SSL client certificate and returns it to the |delegate|. Note:
+ // |delegate| may be called synchronously or asynchronously.
+ //
+ // TODO(davidben): Move this hook to WebContentsDelegate.
virtual void SelectClientCertificate(

Powered by Google App Engine
This is Rietveld 408576698